# Topsis-Abhinav-101903684
It takes an integer as an input and prints it square.

## Installation
```pip install Topsis-Abhinav-101903684```

## How to use it?


## License

© 2022 Abhinav Goyal

This repository is licensed under the MIT license. See LICENSE for details.